# frozen_string_literal: true

# Cookbook:: gitlab-ci-runner
# Library:: cookbook_resource
#
# Copyright:: 2018, Ben Hughes <bmhughes@bmhughes.co.uk>, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

module GitlabCiRunner
  module Cookbook
    # Helpers for cookbook resources
    module ResourceHelpers
      def config_resource_exist?
        begin
          r = find_resource!(:template, new_resource.config)
        rescue Chef::Exceptions::ResourceNotFound
          return false
        end

        return true unless r.nil?

        false
      end

      def config_resource_create
        Chef::Log.info("Creating resource #{new_resource.config}")

        config = toml_load(new_resource.config)

        runners = {}
        runners = config['runners'].nil? ? [] : config.delete('runners')
        global = config

        with_run_context :root do
          find_resource(:chef_gem, 'toml') do
            compile_time true
          end

          edit_resource(:template, new_resource.config) do
            source 'gitlab-runner/config.toml.erb'
            cookbook 'gitlab-ci-runner'

            owner 'root'
            group 'root'
            mode '0600'
            sensitive true

            variables['global'] = global
            variables['runners'] = runners

            helpers(GitlabCiRunner::CommonHelpers)
            helpers(GitlabCiRunner::TomlHelpers)

            action :nothing
            delayed_action :create
          end
        end
      end

      def config_resource_init
        config_resource_create unless config_resource_exist?
      end
    end
  end
end
